log

package
v1.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 25, 2024 License: Apache-2.0 Imports: 6 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Debug added in v1.3.0

func Debug(args ...interface{})

Debug logs a message at level Debug on the standard logger.

func Debugf added in v1.3.0

func Debugf(format string, args ...interface{})

Debugf logs a message at level Debug on the standard logger.

func Debugln added in v1.3.0

func Debugln(args ...interface{})

Debugln logs a message at level Debug on the standard logger.

func E added in v1.4.0

func E() *logrus.Entry

func Error added in v1.3.0

func Error(args ...interface{})

Error logs a message at level Error on the standard logger.

func Errorf added in v1.3.0

func Errorf(format string, args ...interface{})

Errorf logs a message at level Error on the standard logger.

func Errorln added in v1.3.0

func Errorln(args ...interface{})

Errorln logs a message at level Error on the standard logger.

func Fatal added in v1.3.0

func Fatal(args ...interface{})

Fatal logs a message at level Fatal on the standard logger then the process will exit with status set to 1.

func Fatalf added in v1.3.0

func Fatalf(format string, args ...interface{})

Fatalf logs a message at level Fatal on the standard logger then the process will exit with status set to 1.

func Fatalln added in v1.3.0

func Fatalln(args ...interface{})

Fatalln logs a message at level Fatal on the standard logger then the process will exit with status set to 1.

func Info added in v1.3.0

func Info(args ...interface{})

Info logs a message at level Info on the standard logger.

func Infof added in v1.3.0

func Infof(format string, args ...interface{})

Infof logs a message at level Info on the standard logger.

func Infoln added in v1.3.0

func Infoln(args ...interface{})

Infoln logs a message at level Info on the standard logger.

func Init

func Init(opt ...options.Option) error

func Panic added in v1.3.0

func Panic(args ...interface{})

Panic logs a message at level Panic on the standard logger.

func Panicf added in v1.3.0

func Panicf(format string, args ...interface{})

Panicf logs a message at level Panic on the standard logger.

func Panicln added in v1.3.0

func Panicln(args ...interface{})

Panicln logs a message at level Panic on the standard logger.

func Print added in v1.3.0

func Print(args ...interface{})

Print logs a message at level Info on the standard logger.

func Printf added in v1.3.0

func Printf(format string, args ...interface{})

Printf logs a message at level Info on the standard logger.

func Println added in v1.3.0

func Println(args ...interface{})

Println logs a message at level Info on the standard logger.

func SetGlobalField added in v1.3.1

func SetGlobalField(key, value string)

func SetGlobalFields added in v1.3.1

func SetGlobalFields(fields map[string]interface{})

func Trace added in v1.3.0

func Trace(args ...interface{})

Trace logs a message at level Trace on the standard logger.

func Tracef added in v1.3.0

func Tracef(format string, args ...interface{})

Tracef logs a message at level Trace on the standard logger.

func Traceln added in v1.3.0

func Traceln(args ...interface{})

Traceln logs a message at level Trace on the standard logger.

func Warn added in v1.3.0

func Warn(args ...interface{})

Warn logs a message at level Warn on the standard logger.

func Warnf added in v1.3.0

func Warnf(format string, args ...interface{})

Warnf logs a message at level Warn on the standard logger.

func Warning added in v1.3.0

func Warning(args ...interface{})

Warning logs a message at level Warn on the standard logger.

func Warningf added in v1.3.0

func Warningf(format string, args ...interface{})

Warningf logs a message at level Warn on the standard logger.

func Warningln added in v1.3.0

func Warningln(args ...interface{})

Warningln logs a message at level Warn on the standard logger.

func Warnln added in v1.3.0

func Warnln(args ...interface{})

Warnln logs a message at level Warn on the standard logger.

func WithContext added in v1.3.0

func WithContext(ctx context.Context) *logrus.Entry

WithContext creates an entry from the standard logger and adds a context to it.

func WithError added in v1.3.0

func WithError(err error) *logrus.Entry

WithError creates an entry from the standard logger and adds an error to it, using the value defined in ErrorKey as key.

func WithField added in v1.3.0

func WithField(key string, value interface{}) *logrus.Entry

WithField creates an entry from the standard logger and adds a field to it. If you want multiple fields, use `WithFields`.

Note that it doesn't log until you call Debug, Print, Info, Warn, Fatal or Panic on the Entry it returns.

func WithFields added in v1.3.0

func WithFields(fields logrus.Fields) *logrus.Entry

WithFields creates an entry from the standard logger and adds multiple fields to it. This is simply a helper for `WithField`, invoking it once for each field.

Note that it doesn't log until you call Debug, Print, Info, Warn, Fatal or Panic on the Entry it returns.

func WithTime added in v1.3.0

func WithTime(t time.Time) *logrus.Entry

WithTime creates an entry from the standard logger and overrides the time of logs generated with it.

Note that it doesn't log until you call Debug, Print, Info, Warn, Fatal or Panic on the Entry it returns.

Types

type Logger

type Logger struct {
	// contains filtered or unexported fields
}

func L added in v1.4.0

func L() *Logger

func New

func New(opt ...options.Option) (*Logger, error)

func (*Logger) AppendGlobalFields added in v1.4.0

func (logger *Logger) AppendGlobalFields(fields map[string]interface{})

func (*Logger) ClearGlobalFields added in v1.4.0

func (logger *Logger) ClearGlobalFields()

func (*Logger) Config added in v1.3.2

func (logger *Logger) Config(opt ...options.Option) error

func (*Logger) E added in v1.4.0

func (logger *Logger) E() *logrus.Entry

func (*Logger) L added in v1.4.0

func (logger *Logger) L() *logrus.Logger

func (*Logger) SetGlobalField added in v1.3.1

func (logger *Logger) SetGlobalField(key, value string)

func (*Logger) SetGlobalFields added in v1.3.1

func (logger *Logger) SetGlobalFields(fields map[string]interface{})

Jump to